@@ -5,7 +5,7 @@
 
     sphinx-build command-line handling.
 
-    :copyright: Copyright 2007-2009 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -96,7 +96,6 @@ def main(argv):
     error = sys.stderr
     warnfile = None
     confoverrides = {}
-    htmlcontext = {}
     tags = []
     doctreedir = path.join(outdir, '.doctrees')
     for opt, val in opts:
@@ -142,7 +141,7 @@ def main(argv):
                 val = int(val)
             except ValueError:
                 pass
-            htmlcontext[key] = val
+            confoverrides['html_context.%s' % key] = val
         elif opt == '-N':
             nocolor()
         elif opt == '-E':
@@ -158,7 +157,6 @@ def main(argv):
             warnfile = val
         elif opt == '-P':
             use_pdb = True
-    confoverrides['html_context'] = htmlcontext
 
     if warning and warnfile:
         warnfp = open(warnfile, 'w')
@@ -200,10 +198,13 @@ def main(argv):
                 tbpath = save_traceback()
                 print >>error, red('The full traceback has been saved '
                                    'in %s, if you want to report the '
-                                   'issue to the author.' % tbpath)
+                                   'issue to the developers.' % tbpath)
                 print >>error, ('Please also report this if it was a user '
                                 'error, so that a better error message '
                                 'can be provided next time.')
-                print >>error, ('Send reports to sphinx-dev@googlegroups.com. '
-                                'Thanks!')
+                print >>error, (
+                    'Either send bugs to the mailing list at '
+                    '<http://groups.google.com/group/sphinx-dev/>,\n'
+                    'or report them in the tracker at '
+                    '<http://bitbucket.org/birkenfeld/sphinx/issues/>. Thanks!')
             return 1
