@@ -115,8 +115,10 @@ class LiteralInclude(Directive):
                 line=self.lineno)]
 
         encoding = self.options.get('encoding', env.config.source_encoding)
+        codec_info = codecs.lookup(encoding)
         try:
-            f = codecs.open(fn, 'rU', encoding)
+            f = codecs.StreamReaderWriter(open(fn, 'U'),
+                    codec_info.streamreader, codec_info.streamwriter, 'strict')
             lines = f.readlines()
             f.close()
         except (IOError, OSError):
@@ -155,9 +157,9 @@ class LiteralInclude(Directive):
             use = not startafter
             res = []
             for line in lines:
-                if not use and startafter in line:
+                if not use and startafter and startafter in line:
                     use = True
-                elif use and endbefore in line:
+                elif use and endbefore and endbefore in line:
                     use = False
                     break
                 elif use:
