@@ -3,7 +3,7 @@
     sphinx.directives.other
     ~~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: Copyright 2007-2009 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -235,7 +235,7 @@ class Index(Directive):
     option_spec = {}
 
     indextypes = [
-        'single', 'pair', 'triple',
+        'single', 'pair', 'double', 'triple',
     ]
 
     def run(self):
@@ -259,6 +259,8 @@ class Index(Directive):
                 for type in self.indextypes:
                     if entry.startswith(type+':'):
                         value = entry[len(type)+1:].strip()
+                        if type == 'double':
+                            type = 'pair'
                         ne.append((type, value, targetid, value))
                         break
                 # shorthand notation for single entries
@@ -552,7 +554,8 @@ class Only(Directive):
         node.document = self.state.document
         node.line = self.lineno
         node['expr'] = self.arguments[0]
-        self.state.nested_parse(self.content, self.content_offset, node)
+        self.state.nested_parse(self.content, self.content_offset, node,
+                                match_titles=1)
         return [node]
 
 
