@@ -616,7 +616,7 @@ class BuildEnvironment:
         self.note_citations_from(docname, doctree)
         self.build_toc_from(docname, doctree)
 
-        # store time of reading, used to find outdated files
+        # store time of build, for outdated files detection
         self.all_docs[docname] = time.time()
 
         if app:
@@ -936,11 +936,18 @@ class BuildEnvironment:
     def get_toctree_for(self, docname, builder, collapse):
         """Return the global TOC nodetree."""
         doctree = self.get_doctree(self.config.master_doc)
+        toctrees = []
         for toctreenode in doctree.traverse(addnodes.toctree):
-            result = self.resolve_toctree(docname, builder, toctreenode,
-                                          prune=True, collapse=collapse)
-            if result is not None:
-                return result
+            toctree = self.resolve_toctree(docname, builder, toctreenode,
+                                           prune=True, collapse=collapse,
+                                           includehidden=True)
+            toctrees.append(toctree)
+        if not toctrees:
+            return None
+        result = toctrees[0]
+        for toctree in toctrees[1:]:
+            result.extend(toctree.children)
+        return result
 
     # -------
     # these are called from docutils directives and therefore use self.docname
@@ -950,7 +957,8 @@ class BuildEnvironment:
             self.warn(self.docname,
                       'duplicate canonical description name %s, ' % fullname +
                       'other instance in ' +
-                      self.doc2path(self.descrefs[fullname][0]),
+                      self.doc2path(self.descrefs[fullname][0]) +
+                      ', use :noindex: for one of them',
                       line)
         self.descrefs[fullname] = (self.docname, desctype)
 
@@ -1011,7 +1019,7 @@ class BuildEnvironment:
         return doctree
 
     def resolve_toctree(self, docname, builder, toctree, prune=True, maxdepth=0,
-                        titles_only=False, collapse=False):
+                        titles_only=False, collapse=False, includehidden=False):
         """
         Resolve a *toctree* node into individual bullet lists with titles
         as items, returning None (if no containing titles are found) or
@@ -1024,7 +1032,7 @@ class BuildEnvironment:
         If *collapse* is True, all branches not containing docname will
         be collapsed.
         """
-        if toctree.get('hidden', False):
+        if toctree.get('hidden', False) and not includehidden:
             return None
 
         def _walk_depth(node, depth, maxdepth):
@@ -1590,6 +1598,8 @@ class BuildEnvironment:
         else:
             if name in self.descrefs:
                 newname = name
+            elif classname and classname + '.' + name in self.descrefs:
+                newname = classname + '.' + name
             elif modname and modname + '.' + name in self.descrefs:
                 newname = modname + '.' + name
             elif modname and classname and \
