@@ -6,7 +6,7 @@
     Allow graphviz-formatted graphs to be included in Sphinx-generated
     documents inline.
 
-    :copyright: Copyright 2007-2009 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -22,7 +22,7 @@ except ImportError:
 from docutils import nodes
 
 from sphinx.errors import SphinxError
-from sphinx.util import ensuredir
+from sphinx.util import ensuredir, ENOENT, EPIPE
 from sphinx.util.compat import Directive
 
 
@@ -102,6 +102,10 @@ def render_dot(self, code, options, format, prefix='graphviz'):
 
     ensuredir(path.dirname(outfn))
 
+    # graphviz expects UTF-8 by default
+    if isinstance(code, unicode):
+        code = code.encode('utf-8')
+
     dot_args = [self.builder.config.graphviz_dot]
     dot_args.extend(self.builder.config.graphviz_dot_args)
     dot_args.extend(options)
@@ -111,24 +115,32 @@ def render_dot(self, code, options, format, prefix='graphviz'):
     try:
         p = Popen(dot_args, stdout=PIPE, stdin=PIPE, stderr=PIPE)
     except OSError, err:
-        if err.errno != 2:   # No such file or directory
+        if err.errno != ENOENT:   # No such file or directory
             raise
         self.builder.warn('dot command %r cannot be run (needed for graphviz '
                           'output), check the graphviz_dot setting' %
                           self.builder.config.graphviz_dot)
         self.builder._graphviz_warned_dot = True
         return None, None
-    # graphviz expects UTF-8 by default
-    if isinstance(code, unicode):
-        code = code.encode('utf-8')
-    stdout, stderr = p.communicate(code)
+    try:
+        # Graphviz may close standard input when an error occurs,
+        # resulting in a broken pipe on communicate()
+        stdout, stderr = p.communicate(code)
+    except OSError, err:
+        if err.errno != EPIPE:
+            raise
+        # in this case, read the standard output and standard error streams
+        # directly, to get the error message(s)
+        stdout, stderr = p.stdout.read(), p.stderr.read()
+        p.wait()
     if p.returncode != 0:
         raise GraphvizError('dot exited with error:\n[stderr]\n%s\n'
                             '[stdout]\n%s' % (stderr, stdout))
     return relfn, outfn
 
 
-def render_dot_html(self, node, code, options, prefix='graphviz', imgcls=None):
+def render_dot_html(self, node, code, options, prefix='graphviz',
+                    imgcls=None, alt=None):
     try:
         fname, outfn = render_dot(self, code, options, 'png', prefix)
     except GraphvizError, exc:
@@ -145,16 +157,17 @@ def render_dot_html(self, node, code, options, prefix='graphviz', imgcls=None):
         finally:
             mapfile.close()
         imgcss = imgcls and 'class="%s"' % imgcls or ''
+        if alt is None:
+            alt = self.encode(code).strip()
         if len(imgmap) == 2:
             # nothing in image map (the lines are <map> and </map>)
             self.body.append('<img src="%s" alt="%s" %s/>\n' %
-                             (fname, self.encode(code).strip(), imgcss))
+                             (fname, alt, imgcss))
         else:
             # has a map: get the name of the map and connect the parts
             mapname = mapname_re.match(imgmap[0]).group(1)
             self.body.append('<img src="%s" alt="%s" usemap="#%s" %s/>\n' %
-                             (fname, self.encode(code).strip(),
-                              mapname, imgcss))
+                             (fname, alt, mapname, imgcss))
             self.body.extend(imgmap)
     self.body.append('</p>\n')
     raise nodes.SkipNode
