@@ -32,7 +32,7 @@
     The graph is inserted as a PNG+image map into HTML and a PDF in
     LaTeX.
 
-    :copyright: Copyright 2007-2009 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -301,7 +301,7 @@ class InheritanceDiagram(Directive):
         node['graph'] = graph
         # Store the original content for use as a hash
         node['parts'] = self.options.get('parts', 0)
-        node['content'] = ' '.join(class_names)
+        node['content'] = ', '.join(class_names)
         return [node]
 
 
@@ -329,7 +329,8 @@ def html_visit_inheritance_diagram(self, node):
             urls[child['reftitle']] = '#' + child.get('refid')
 
     dotcode = graph.generate_dot(name, parts, urls, env=self.builder.env)
-    render_dot_html(self, node, dotcode, [], 'inheritance', 'inheritance')
+    render_dot_html(self, node, dotcode, [], 'inheritance', 'inheritance',
+                    alt='Inheritance diagram of ' + node['content'])
     raise nodes.SkipNode
 
 
