@@ -8,12 +8,13 @@
     all todos of your project and lists them along with a backlink to the
     original location.
 
-    :copyright: Copyright 2007-2009 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 from docutils import nodes
 
+from sphinx.environment import NoUri
 from sphinx.util.compat import Directive, make_admonition
 
 class todo_node(nodes.Admonition, nodes.Element): pass
@@ -41,20 +42,31 @@ class Todo(Directive):
         ad = make_admonition(todo_node, self.name, [_('Todo')], self.options,
                              self.content, self.lineno, self.content_offset,
                              self.block_text, self.state, self.state_machine)
+        ad[0].line = self.lineno
+        return [targetnode] + ad
 
-        # Attach a list of all todos to the environment,
-        # the todolist works with the collected todo nodes
-        if not hasattr(env, 'todo_all_todos'):
-            env.todo_all_todos = []
+
+def process_todos(app, doctree):
+    # collect all todos in the environment
+    # this is not done in the directive itself because it some transformations
+    # must have already been run, e.g. substitutions
+    env = app.builder.env
+    if not hasattr(env, 'todo_all_todos'):
+        env.todo_all_todos = []
+    for node in doctree.traverse(todo_node):
+        try:
+            targetnode = node.parent[node.parent.index(node) - 1]
+            if not isinstance(targetnode, nodes.target):
+                raise IndexError
+        except IndexError:
+            targetnode = None
         env.todo_all_todos.append({
             'docname': env.docname,
-            'lineno': self.lineno,
-            'todo': ad[0].deepcopy(),
+            'lineno': node.line,
+            'todo': node.deepcopy(),
             'target': targetnode,
         })
 
-        return [targetnode] + ad
-
 
 class TodoList(Directive):
     """
@@ -104,9 +116,13 @@ def process_todo_nodes(app, doctree, fromdocname):
             newnode = nodes.reference('', '')
             innernode = nodes.emphasis(_('here'), _('here'))
             newnode['refdocname'] = todo_info['docname']
-            newnode['refuri'] = app.builder.get_relative_uri(
-                fromdocname, todo_info['docname'])
-            newnode['refuri'] += '#' + todo_info['target']['refid']
+            try:
+                newnode['refuri'] = app.builder.get_relative_uri(
+                    fromdocname, todo_info['docname'])
+                newnode['refuri'] += '#' + todo_info['target']['refid']
+            except NoUri:
+                # ignore if no URI can be determined, e.g. for LaTeX output
+                pass
             newnode.append(innernode)
             para += newnode
             para += nodes.Text('.)', '.)')
@@ -147,6 +163,7 @@ def setup(app):
 
     app.add_directive('todo', Todo)
     app.add_directive('todolist', TodoList)
+    app.connect('doctree-read', process_todos)
     app.connect('doctree-resolved', process_todo_nodes)
     app.connect('env-purge-doc', purge_todos)
 
