@@ -5,14 +5,16 @@
 
     Utility functions for Sphinx.
 
-    :copyright: Copyright 2007-2009 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 import os
 import re
 import sys
+import stat
 import time
+import errno
 import types
 import shutil
 import fnmatch
@@ -21,6 +23,13 @@ import posixpath
 import traceback
 from os import path
 
+import docutils
+import sphinx
+
+# Errnos that we need.
+EEXIST = getattr(errno, 'EEXIST', 0)
+ENOENT = getattr(errno, 'ENOENT', 0)
+EPIPE  = getattr(errno, 'EPIPE', 0)
 
 # Generally useful regular expressions.
 ws_re = re.compile(r'\s+')
@@ -63,7 +72,8 @@ def ensuredir(path):
     try:
         os.makedirs(path)
     except OSError, err:
-        if not err.errno == 17:
+        # 0 for Jython/Win32
+        if err.errno not in [0, EEXIST]:
             raise
 
 
@@ -206,6 +216,9 @@ def save_traceback():
     """
     exc = traceback.format_exc()
     fd, path = tempfile.mkstemp('.log', 'sphinx-err-')
+    os.write(fd, '# Sphinx version: %s\n' % sphinx.__version__)
+    os.write(fd, '# Docutils version: %s %s\n' % (docutils.__version__,
+                                                  docutils.__version_details__))
     os.write(fd, exc)
     os.close(fd)
     return path
@@ -265,7 +278,6 @@ def patfilter(names, pat):
     Return the subset of the list NAMES that match PAT.
     Adapted from fnmatch module.
     """
-    result = []
     if pat not in _pat_cache:
         _pat_cache[pat] = re.compile(_translate_pattern(pat))
     match = _pat_cache[pat].match
@@ -393,11 +405,21 @@ def movefile(source, dest):
     os.rename(source, dest)
 
 
+def copytimes(source, dest):
+    """Copy a file's modification times."""
+    st = os.stat(source)
+    if hasattr(os, 'utime'):
+        os.utime(dest, (st.st_atime, st.st_mtime))
+
+
 def copyfile(source, dest):
     """Copy a file and its modification times, if possible."""
     shutil.copyfile(source, dest)
-    try: shutil.copystat(source, dest)
-    except shutil.Error: pass
+    try:
+        # don't do full copystat because the source may be read-only
+        copytimes(source, dest)
+    except OSError:
+        pass
 
 
 def copy_static_entry(source, target, builder, context={}):
@@ -419,6 +441,14 @@ def copy_static_entry(source, target, builder, context={}):
         shutil.copytree(source, target)
 
 
+def clean_astext(node):
+    """Like node.astext(), but ignore images."""
+    node = node.deepcopy()
+    for img in node.traverse(docutils.nodes.image):
+        img['alt'] = ''
+    return node.astext()
+
+
 # monkey-patch Node.traverse to get more speed
 # traverse() is called so many times during a build that it saves
 # on average 20-25% overall build time!
