@@ -5,7 +5,7 @@
 
     Test the entire build process with the test root.
 
-    :copyright: Copyright 2007-2009 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -77,6 +77,8 @@ HTML_XPATH = {
         ".//pre": u'Max Strauß',
         ".//a[@href='_downloads/img.png']": '',
         ".//a[@href='_downloads/img1.png']": '',
+        ".//pre": u'"quotes"',
+        ".//pre": u"'included'",
     },
     'autodoc.html': {
         ".//dt[@id='test_autodoc.Class']": '',
@@ -106,6 +108,7 @@ HTML_XPATH = {
     },
     'contents.html': {
         ".//meta[@name='hc'][@content='hcval']": '',
+        ".//meta[@name='hc_co'][@content='hcval_co']": '',
         ".//meta[@name='testopt'][@content='testoverride']": '',
         #".//td[@class='label']": r'\[Ref1\]',   # docutils 0.5 only
         ".//td[@class='label']": '',
@@ -177,6 +180,7 @@ def check_xpath(etree, fname, path, check):
                            [node.text for node in nodes]))
 
 @gen_with_app(buildername='html', warning=html_warnfile, cleanenv=True,
+              confoverrides={'html_context.hckey_co': 'hcval_co'},
               tags=['testtag'])
 def test_html(app):
     app.builder.build_all()
